Lattices (:mod:`erlab.lattice`)
===============================

.. automodule:: erlab.lattice







   .. rubric:: Functions

   .. autosummary::

      angle_between
      abc2avec
      avec2abc
      to_reciprocal
      to_real
